@@ -23,7 +23,7 @@ LOGGER = logging.getLogger(__name__)
 timestr = time.strftime("%Y%m%d-%H%M%S")
 
 
-def prepare_file_name_saving(prefix: str, file_name: str, ending: str) -> str:
+def prepare_file_name_saving(prefix: str, file_name: str, suffix: str) -> str:
     """The prepare_file_name_saving function takes a prefix and file name as
     input. It checks to see if the directory exists, and makes it if not. Then
     it returns the full path of the file.
@@ -36,20 +36,20 @@ def prepare_file_name_saving(prefix: str, file_name: str, ending: str) -> str:
     """
     check_make_dir(prefix)
     file_name = make_full_filename(prefix, file_name)
-    file_name = check_file_name(file_name, ending)
+    file_name = check_file_name(file_name, suffix)
     return file_name
 
 
-def insert_string_in_file_name(file_name: str, insertion: str, ending: str) -> str:
+def insert_string_in_file_name(file_name: str, insertion: str, suffix: str) -> str:
     """
     The insert_string_in_file_name function takes a file_name and inserts a string into the name.
         The insertion is placed before the extension of the file_name, or if there is no extension,
-        it will be placed at the end of the file_name with an ending specified by you.
+        it will be placed at the end of the file_name with an suffix specified by you.
 
 
     :param file_name:str: Used to Specify the file name that you want to insert a string into.
     :param insertion:str: Used to Specify the string that will be inserted into the file name.
-    :param ending:str: Used to Specify the file ending.
+    :param suffix:str: Used to Specify the file suffix.
     :return: A string.
 
     :doc-author: Julian M. Kleber
@@ -57,24 +57,24 @@ def insert_string_in_file_name(file_name: str, insertion: str, ending: str) -> s
 
     root, ext = os.path.splitext(file_name)
 
-    if ending is None and not ext:
+    if suffix is None and not ext:
         raise ValueError(
-            "You must either specify an ending in the file_name or pass an ending through the \
-            ending argument. For example the file_name could be 'foo.bar' or you pass \
-            file_name'foo' with ending = '.bar'"
+            "You must either specify an suffix in the file_name or pass an suffix through the \
+            suffix argument. For example the file_name could be 'foo.bar' or you pass \
+            file_name'foo' with suffix = '.bar'"
         )
-    if ending is not None:
-        if not ending.startswith("."):
-            ending = "." + ending
+    if suffix is not None:
+        if not suffix.startswith("."):
+            suffix = "." + suffix
 
     if not ext:
-        file_name = file_name + "_" + insertion + ending
+        file_name = file_name + "_" + insertion + suffix
     else:
         file_name = root + "_" + insertion + ext
     return file_name
 
 
-def check_file_name(file_name: str, ending: str) -> str:
+def check_file_name(file_name: str, suffix: str) -> str:
     """The check_name_plot function checks that the file_name ends with .png.
     If it does not, then check_name_plot appends .png to the end of the
     file_name.
@@ -87,9 +87,9 @@ def check_file_name(file_name: str, ending: str) -> str:
     name = file_name
     ext = os.path.splitext(file_name)[1]
     if not ext:
-        if not ending.startswith("."):
-            ending = "." + ending
-        name += ending
+        if not suffix.startswith("."):
+            suffix = "." + suffix
+        name += suffix
     return name
 
 
